/* GUI_Playlist.h */

/* Copyright (C) 2011  Lucio Carreras
 *
 * This file is part of sayonara player
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/*
 * GUI_Playlist.h
 *
 *  Created on: Apr 6, 2011
 *      Author: luke
 */

#ifndef GUI_PLAYLIST_H_
#define GUI_PLAYLIST_H_

#include "TabWidget/PlaylistTabWidget.h"
#include "PlaylistMenu.h"

#include "GUI/Playlist/ui_GUI_Playlist.h"
#include "GUI/InfoDialog/GUI_InfoDialog.h"
#include "Components/Playlist/PlaylistHandler.h"
#include "Helper/PlaylistMode.h"

#include <QTextEdit>
#include <QFocusEvent>
#include <QKeyEvent>


class GUI_Playlist : public SayonaraWidget, private Ui::Playlist_Window
{
	Q_OBJECT

public:
	GUI_Playlist(QWidget *parent);
	~GUI_Playlist();

	void dragEnterEvent(QDragEnterEvent* event);
	void dragLeaveEvent(QDragLeaveEvent* event);
	void dropEvent(QDropEvent* event);
	void dragMoveEvent(QDragMoveEvent* event);


public slots:


	void set_playlist_type(Playlist::Type playlist_type);


private slots:

	// triggered from playlist
	void playlist_track_changed(int row, int playlist_idx); // GUI_Playlist.cpp
	void playlist_fill(const PlaylistPtr& pl); // GUI_Playlist.cpp
	void playlist_added(int idx); // GUI_PlaylistTabs.cpp
	void playlist_name_changed(int idx);// GUI_PlaylistTabs.cpp


	// triggered by GUI
	void tab_playlist_clicked(int); // GUI_PlaylistTabs.cpp
	void tab_close_playlist_clicked(int); // GUI_PlaylistTabs.cpp
	void tab_reset_clicked(int idx); // GUI_PlaylistTabs.cpp
	void tab_save_playlist_clicked(int idx); // GUI_PlaylistTabs.cpp
	void tab_save_playlist_as_clicked(int idx, const QString& str); // GUI_PlaylistTabs.cpp
	void tab_rename_clicked(int idx, const QString& str);
	void tab_delete_playlist_clicked(int idx); // GUI_PlaylistTabs.cpp

	void metadata_dropped(const MetaDataList&, int);
	void rows_moved(const IdxList&, int);
	void rows_removed(const IdxList&);
	void sel_changed(const MetaDataList&, const IdxList&);
	void double_clicked(int);

	void add_playlist_button_pressed();
	void clear_button_pressed();


	// triggered from ContextMenu
	void menu_info_clicked();
	void menu_edit_clicked();

	// called by playmanager
	void playstate_changed(PlayManager::PlayState state);
	void playlist_finished();


	void _sl_show_numbers_changed();
	void _sl_small_playlist_items_changed();
	void _sl_library_path_changed();


private:

	PlayManager*			_play_manager;
	PlaylistHandler*		_playlist;
	GUI_InfoDialog*			_info_dialog;
	PlaylistMode			_playlist_mode;
	Playlist::Type			_playlist_type;
	QList<PlaylistView*>	_playlist_views;

	QVector<qint64>			_total_time;

	PlaylistView* get_view_by_idx(int idx);
	PlaylistView* get_current_view();

	void init_playlist_view(const PlaylistView* pl_view);
	void set_total_time_label(qint64 dur_ms=0);
	void tab_clear_all_icons();

	GlobalMessage::Answer show_save_message_box(PlaylistDBInterface::SaveAsAnswer answer);


protected:
	void changeEvent(QEvent* e) override;
	void resizeEvent(QResizeEvent *e) override;
	void language_changed() override;
};



#endif /* GUI_PLAYLIST_H_ */
